# PythonLib aRTist

This Python library can be used to remotely and automatically control the "aRTist" X-ray simulation tool, which was developed by [BAM](https://www.bam.de).

Please read the [documentation](https://bamresearch.github.io/aRTist-PythonLib/) to get started.

Visit the [website](https://www.artist.bam.de) and [online guide](https://bamresearch.github.io/aRTist-handbook/) for more information on aRTist.
